# Michigan.Ods.Sdk.Api.ExpendituresApi

All URIs are relative to *https://api-mi.doubleline.us:443/ods-pd3/data/v3/2023*

Method | HTTP request | Description
------------- | ------------- | -------------
[**DeleteExpenditureById**](ExpendituresApi.md#deleteexpenditurebyid) | **DELETE** /MI/expenditures/{id} | Deletes an existing resource using the resource identifier.
[**DeletesExpenditures**](ExpendituresApi.md#deletesexpenditures) | **GET** /MI/expenditures/deletes | Retrieves deleted resources based on change version.
[**GetExpenditures**](ExpendituresApi.md#getexpenditures) | **GET** /MI/expenditures | Retrieves specific resources using the resource&#39;s property values (using the \&quot;Get\&quot; pattern).
[**GetExpendituresById**](ExpendituresApi.md#getexpendituresbyid) | **GET** /MI/expenditures/{id} | Retrieves a specific resource using the resource&#39;s identifier (using the \&quot;Get By Id\&quot; pattern).
[**PostExpenditure**](ExpendituresApi.md#postexpenditure) | **POST** /MI/expenditures | Creates or updates resources based on the natural key values of the supplied resource.
[**PutExpenditure**](ExpendituresApi.md#putexpenditure) | **PUT** /MI/expenditures/{id} | Updates or creates a resource based on the resource identifier.


<a name="deleteexpenditurebyid"></a>
# **DeleteExpenditureById**
> void DeleteExpenditureById (string id, string ifMatch = null)

Deletes an existing resource using the resource identifier.

The DELETE operation is used to delete an existing resource by identifier. If the resource doesn't exist, an error will result (the resource will not be found).

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class DeleteExpenditureByIdExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var id = id_example;  // string | A resource identifier that uniquely identifies the resource.
            var ifMatch = ifMatch_example;  // string | The ETag header value used to prevent the DELETE from removing a resource modified by another consumer. (optional) 

            try
            {
                // Deletes an existing resource using the resource identifier.
                apiInstance.DeleteExpenditureById(id, ifMatch);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.DeleteExpenditureById: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| A resource identifier that uniquely identifies the resource. | 
 **ifMatch** | **string**| The ETag header value used to prevent the DELETE from removing a resource modified by another consumer. | [optional] 

### Return type

void (empty response body)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletesexpenditures"></a>
# **DeletesExpenditures**
> List<MiExpenditure> DeletesExpenditures (int? offset = null, int? limit = null, int? minChangeVersion = null, int? maxChangeVersion = null)

Retrieves deleted resources based on change version.

The DELETES operation is used to retrieve deleted resources.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class DeletesExpendituresExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var offset = 56;  // int? | Indicates how many items should be skipped before returning results. (optional)  (default to 0)
            var limit = 56;  // int? | Indicates the maximum number of items that should be returned in the results. (optional)  (default to 25)
            var minChangeVersion = 56;  // int? | Used in synchronization to set sequence minimum ChangeVersion (optional) 
            var maxChangeVersion = 56;  // int? | Used in synchronization to set sequence maximum ChangeVersion (optional) 

            try
            {
                // Retrieves deleted resources based on change version.
                List&lt;MiExpenditure&gt; result = apiInstance.DeletesExpenditures(offset, limit, minChangeVersion, maxChangeVersion);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.DeletesExpenditures: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **offset** | **int?**| Indicates how many items should be skipped before returning results. | [optional] [default to 0]
 **limit** | **int?**| Indicates the maximum number of items that should be returned in the results. | [optional] [default to 25]
 **minChangeVersion** | **int?**| Used in synchronization to set sequence minimum ChangeVersion | [optional] 
 **maxChangeVersion** | **int?**| Used in synchronization to set sequence maximum ChangeVersion | [optional] 

### Return type

[**List<MiExpenditure>**](MiExpenditure.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getexpenditures"></a>
# **GetExpenditures**
> List<MiExpenditure> GetExpenditures (int? offset = null, int? limit = null, int? minChangeVersion = null, int? maxChangeVersion = null, bool? totalCount = null, string functionCodeDescriptor = null, string fundCodeDescriptor = null, string grantCodeDescriptor = null, string objectCodeDescriptor = null, int? fiscalYear = null, int? educationOrganizationId = null, int? schoolId = null, string programCodeDescriptor = null, double? amount = null, string expenditureOtherOptional = null, string id = null)

Retrieves specific resources using the resource's property values (using the \"Get\" pattern).

This GET operation provides access to resources using the \"Get\" search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class GetExpendituresExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var offset = 56;  // int? | Indicates how many items should be skipped before returning results. (optional)  (default to 0)
            var limit = 56;  // int? | Indicates the maximum number of items that should be returned in the results. (optional)  (default to 25)
            var minChangeVersion = 56;  // int? | Used in synchronization to set sequence minimum ChangeVersion (optional) 
            var maxChangeVersion = 56;  // int? | Used in synchronization to set sequence maximum ChangeVersion (optional) 
            var totalCount = true;  // bool? | Indicates if the total number of items available should be returned in the 'Total-Count' header of the response.  If set to false, 'Total-Count' header will not be provided. (optional)  (default to false)
            var functionCodeDescriptor = functionCodeDescriptor_example;  // string | To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired. (optional) 
            var fundCodeDescriptor = fundCodeDescriptor_example;  // string | The independent fisal and accounting entity for expenditure transaction. (optional) 
            var grantCodeDescriptor = grantCodeDescriptor_example;  // string | To indicate various grant programs/funding source. (optional) 
            var objectCodeDescriptor = objectCodeDescriptor_example;  // string | To indicate the service or commodity obtained as the result of a specific expenditure. (optional) 
            var fiscalYear = 56;  // int? | Denotes the fiscal year for which the expenditure is submitted. (optional) 
            var educationOrganizationId = 56;  // int? | The identifier assigned to an education organization. (optional) 
            var schoolId = 56;  // int? | The identifier assigned to a school. (optional) 
            var programCodeDescriptor = programCodeDescriptor_example;  // string | To indicate a plan of activities and procedures designed to accomplish predetermined objective or set of allied objectives. (optional) 
            var amount = 1.2;  // double? | Amount for the expenditure submitted. (optional) 
            var expenditureOtherOptional = expenditureOtherOptional_example;  // string | A dimension available to further define a school district's activities. (optional) 
            var id = id_example;  // string |  (optional) 

            try
            {
                // Retrieves specific resources using the resource's property values (using the \"Get\" pattern).
                List&lt;MiExpenditure&gt; result = apiInstance.GetExpenditures(offset, limit, minChangeVersion, maxChangeVersion, totalCount, functionCodeDescriptor, fundCodeDescriptor, grantCodeDescriptor, objectCodeDescriptor, fiscalYear, educationOrganizationId, schoolId, programCodeDescriptor, amount, expenditureOtherOptional, id);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.GetExpenditures: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **offset** | **int?**| Indicates how many items should be skipped before returning results. | [optional] [default to 0]
 **limit** | **int?**| Indicates the maximum number of items that should be returned in the results. | [optional] [default to 25]
 **minChangeVersion** | **int?**| Used in synchronization to set sequence minimum ChangeVersion | [optional] 
 **maxChangeVersion** | **int?**| Used in synchronization to set sequence maximum ChangeVersion | [optional] 
 **totalCount** | **bool?**| Indicates if the total number of items available should be returned in the &#39;Total-Count&#39; header of the response.  If set to false, &#39;Total-Count&#39; header will not be provided. | [optional] [default to false]
 **functionCodeDescriptor** | **string**| To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired. | [optional] 
 **fundCodeDescriptor** | **string**| The independent fisal and accounting entity for expenditure transaction. | [optional] 
 **grantCodeDescriptor** | **string**| To indicate various grant programs/funding source. | [optional] 
 **objectCodeDescriptor** | **string**| To indicate the service or commodity obtained as the result of a specific expenditure. | [optional] 
 **fiscalYear** | **int?**| Denotes the fiscal year for which the expenditure is submitted. | [optional] 
 **educationOrganizationId** | **int?**| The identifier assigned to an education organization. | [optional] 
 **schoolId** | **int?**| The identifier assigned to a school. | [optional] 
 **programCodeDescriptor** | **string**| To indicate a plan of activities and procedures designed to accomplish predetermined objective or set of allied objectives. | [optional] 
 **amount** | **double?**| Amount for the expenditure submitted. | [optional] 
 **expenditureOtherOptional** | **string**| A dimension available to further define a school district&#39;s activities. | [optional] 
 **id** | **string**|  | [optional] 

### Return type

[**List<MiExpenditure>**](MiExpenditure.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getexpendituresbyid"></a>
# **GetExpendituresById**
> MiExpenditure GetExpendituresById (string id, string ifNoneMatch = null)

Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).

This GET operation retrieves a resource by the specified resource identifier.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class GetExpendituresByIdExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var id = id_example;  // string | A resource identifier that uniquely identifies the resource.
            var ifNoneMatch = ifNoneMatch_example;  // string | The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. (optional) 

            try
            {
                // Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).
                MiExpenditure result = apiInstance.GetExpendituresById(id, ifNoneMatch);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.GetExpendituresById: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| A resource identifier that uniquely identifies the resource. | 
 **ifNoneMatch** | **string**| The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. | [optional] 

### Return type

[**MiExpenditure**](MiExpenditure.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="postexpenditure"></a>
# **PostExpenditure**
> void PostExpenditure (MiExpenditure expenditure)

Creates or updates resources based on the natural key values of the supplied resource.

The POST operation can be used to create or update resources. In database terms, this is often referred to as an \"upsert\" operation (insert + update). Clients should NOT include the resource \"id\" in the JSON body because it will result in an error (you must use a PUT operation to update a resource by \"id\"). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class PostExpenditureExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var expenditure = new MiExpenditure(); // MiExpenditure | The JSON representation of the \"expenditure\" resource to be created or updated.

            try
            {
                // Creates or updates resources based on the natural key values of the supplied resource.
                apiInstance.PostExpenditure(expenditure);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.PostExpenditure: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **expenditure** | [**MiExpenditure**](MiExpenditure.md)| The JSON representation of the \&quot;expenditure\&quot; resource to be created or updated. | 

### Return type

void (empty response body)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="putexpenditure"></a>
# **PutExpenditure**
> void PutExpenditure (string id, MiExpenditure expenditure, string ifMatch = null)

Updates or creates a resource based on the resource identifier.

The PUT operation is used to update or create a resource by identifier. If the resource doesn't exist, the resource will be created using that identifier. Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource \"id\" is provided in the JSON body, it will be ignored as well.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Models;

namespace Example
{
    public class PutExpenditureExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new ExpendituresApi();
            var id = id_example;  // string | A resource identifier that uniquely identifies the resource.
            var expenditure = new MiExpenditure(); // MiExpenditure | The JSON representation of the \"expenditure\" resource to be created or updated.
            var ifMatch = ifMatch_example;  // string | The ETag header value used to prevent the PUT from updating a resource modified by another consumer. (optional) 

            try
            {
                // Updates or creates a resource based on the resource identifier.
                apiInstance.PutExpenditure(id, expenditure, ifMatch);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling ExpendituresApi.PutExpenditure: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| A resource identifier that uniquely identifies the resource. | 
 **expenditure** | [**MiExpenditure**](MiExpenditure.md)| The JSON representation of the \&quot;expenditure\&quot; resource to be created or updated. | 
 **ifMatch** | **string**| The ETag header value used to prevent the PUT from updating a resource modified by another consumer. | [optional] 

### Return type

void (empty response body)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

